from .__version__ import __version__, __version_info__  # noqa

__author__ = "Carl Oscar Aaro"
__email__ = "hello@carloscar.com"

__all__ = [
    "__version__",
    "__version_info__",
    "__author__",
    "__email__",
]
